pub fn VR_IsHmdPresent() -> boolExpand description
Returns true if there is an HMD attached. This check is as lightweight as possible and can be called outside of VR_Init/VR_Shutdown. It should be used when an application wants to know if initializing VR is a possibility but isn’t ready to take that step yet.