Struct HiddenAreaMesh_t

#[repr(C, align(8))]
pub struct HiddenAreaMesh_t { /* private fields */ }
The mesh to draw into the stencil (or depth) buffer to perform early stencil (or depth) kills of pixels that will never appear on the HMD. This mesh draws on all the pixels that will be hidden after distortion.

If the HMD does not provide a visible area mesh pVertexData will be NULL and unTriangleCount will be 0.